DocumentMessage class

Inheritance

Constructors

DocumentMessage({required User author, required String? time, int? stage = 0, required String id, required String documentSize, required String documentFormat, required String documentName, MessageTheme? theme})

Properties

author ↔ User
getter/setter pairinherited
documentFormat → String
final
documentName → String
final
documentSize → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stage ↔ int?
getter/setter pairinherited
theme → MessageTheme?
finalinherited
time ↔ String?
getter/setter pairinherited

Methods

builder(BuildContext ctx, bool showUserAvatar, bool showMessageStatus, bool showUsername, User loggedInUser, ChatTheme theme, AuthorDetailsLocation authorDetailsLocation) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited