ChatTheme class abstract

Implementers

Constructors

ChatTheme({Color? backgroundColor, DecorationImage? backgroundImage, required BorderRadius? imageBorderRadius, required Color? userStatusColor, required Color primaryColor, required Widget seenIcon, required Widget sentIcon, required Widget sendingFailedIcon, required EdgeInsetsGeometry usernamePadding, required EdgeInsetsGeometry bodyPadding, required TextStyle timeTextStyle, required TextStyle timestampTextStyle, required TextStyle usernameTextStyle, required TextStyle avatarTextStyle, required Color defaultUserColor, required double userAvatarRadius, required Widget verificationBadge, Color? inputBackgroundColor, Color? iconColor, MessageTheme? inwardMessageTheme, MessageTheme? outwardMessageTheme, MessageTheme? actionMessageTheme})

Properties

actionMessageTheme → MessageTheme?
final
avatarTextStyle → TextStyle
The text style for user avatars.
final
backgroundColor → Color?
The background color for the chat widget.
final
backgroundImage → DecorationImage?
The background image for the chat widget.
final
bodyPadding → EdgeInsetsGeometry
The padding around the chat body.
final
defaultUserColor → Color
The default color for user avatars.
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
The primary color used for various elements in the chat.
final
imageBorderRadius → BorderRadius?
The border radius for user images.
final
inputBackgroundColor → Color?
The text input background color used for various elements in the chat.
final
inwardMessageTheme → MessageTheme?
final
outwardMessageTheme → MessageTheme?
final
primaryColor → Color
The primary color used for various elements in the chat.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seenIcon → Widget
A widget representing an icon for a seen message.
final
sendingFailedIcon → Widget
A widget representing an icon for a sending message that failed.
final
sentIcon → Widget
A widget representing an icon for a sent message.
final
timestampTextStyle → TextStyle
The text style for message timestamps.
final
timeTextStyle → TextStyle
The text style for timestamps in messages.
final
userAvatarRadius → double
The radius of user avatars.
final
usernamePadding → EdgeInsetsGeometry
The padding around usernames.
final
usernameTextStyle → TextStyle
The text style for usernames.
final
userStatusColor → Color?
The color for the user's status indicator.
final
verificationBadge → Widget
A widget to display a verification badge for the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited