DefaultChatTheme class

Inheritance

Constructors

DefaultChatTheme({BorderRadius? imageBorderRadius, Color? backgroundColor, DecorationImage? backgroundImage = const DecorationImage(image: CachedNetworkImageProvider("https://i.pinimg.com/736x/85/ec/df/85ecdf1c3611ecc9b7fa85282d9526e0.jpg"), fit: BoxFit.cover), Color? userStatusColor = Colors.green, Widget verificationBadge = const Iconify(Ic.sharp_verified, color: Colors.green, size: 14), TextStyle timestampTextStyle = const TextStyle(fontSize: 14, color: Color.fromARGB(255, 114, 114, 114), fontWeight: FontWeight.w500), MessageTheme? inwardMessageTheme = const MessageTheme(linkPreviewTitleStyle: TextStyle(color: Colors.white, fontWeight: FontWeight.bold), linkPreviewTextStyle: TextStyle(color: Color.fromARGB(255, 182, 182, 182)), contentTextStyle: TextStyle(color: Color.fromARGB(255, 225, 225, 225), fontSize: 14, fontWeight: FontWeight.w500), borderRadius: BorderRadius.only(topLeft: Radius.circular(20), topRight: Radius.circular(20), bottomRight: Radius.circular(20), bottomLeft: Radius.circular(5)), backgroundColor: Color(0xff373E4E), messageWidth: 0.7, padding: EdgeInsets.all(10.0), margin: EdgeInsets.only(top: 20), urlTextStyle: TextStyle(color: Colors.blue)), MessageTheme? outwardMessageTheme = const MessageTheme(linkPreviewTitleStyle: TextStyle(color: Colors.white, fontWeight: FontWeight.bold), linkPreviewTextStyle: TextStyle(color: Color.fromARGB(255, 182, 182, 182)), borderRadius: BorderRadius.only(topLeft: Radius.circular(20), topRight: Radius.circular(20), bottomRight: Radius.circular(5), bottomLeft: Radius.circular(20)), contentTextStyle: TextStyle(color: Color.fromARGB(255, 225, 225, 225), fontSize: 14, fontWeight: FontWeight.w500), backgroundColor: Color(0xff7A8194), messageWidth: 0.7, padding: EdgeInsets.all(10.0), margin: EdgeInsets.only(top: 20)), MessageTheme? actionMessageTheme = const MessageTheme(contentTextStyle: TextStyle(fontSize: 14, color: Color.fromARGB(255, 114, 114, 114), fontWeight: FontWeight.w500), backgroundColor: null, margin: EdgeInsets.only(top: 15, left: 20, right: 20), urlTextStyle: TextStyle(color: Colors.blue)), EdgeInsetsGeometry bodyPadding = const EdgeInsets.symmetric(vertical: 10, horizontal: 20), EdgeInsetsGeometry usernamePadding = const EdgeInsets.all(2), Widget seenIcon = const MessageStatus(2), Widget sentIcon = const MessageStatus(1), Widget sendingFailedIcon = const Iconify(Mdi.alert_circle_outline, color: Colors.red), TextStyle timeTextStyle = const TextStyle(color: Colors.white, fontSize: 12), TextStyle usernameTextStyle = const TextStyle(fontSize: 14, fontWeight: FontWeight.bold), TextStyle avatarTextStyle = const TextStyle(color: Colors.white, fontWeight: FontWeight.bold, fontSize: 22, fontFamily: 'Satoshi'), Color defaultUserColor = Colors.blue, double userAvatarRadius = 10.0, Color? iconColor = Colors.white, Color? inputBackgroundColor, required Color primaryColor})

Properties

actionMessageTheme → MessageTheme?
finalinherited
avatarTextStyle → TextStyle
The text style for user avatars.
finalinherited
backgroundColor → Color?
The background color for the chat widget.
finalinherited
backgroundImage → DecorationImage?
The background image for the chat widget.
finalinherited
bodyPadding → EdgeInsetsGeometry
The padding around the chat body.
finalinherited
defaultUserColor → Color
The default color for user avatars.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
The primary color used for various elements in the chat.
finalinherited
imageBorderRadius → BorderRadius?
The border radius for user images.
finalinherited
inputBackgroundColor → Color?
The text input background color used for various elements in the chat.
finalinherited
inwardMessageTheme → MessageTheme?
finalinherited
outwardMessageTheme → MessageTheme?
finalinherited
primaryColor → Color
The primary color used for various elements in the chat.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seenIcon → Widget
A widget representing an icon for a seen message.
finalinherited
sendingFailedIcon → Widget
A widget representing an icon for a sending message that failed.
finalinherited
sentIcon → Widget
A widget representing an icon for a sent message.
finalinherited
timestampTextStyle → TextStyle
The text style for message timestamps.
finalinherited
timeTextStyle → TextStyle
The text style for timestamps in messages.
finalinherited
userAvatarRadius → double
The radius of user avatars.
finalinherited
usernamePadding → EdgeInsetsGeometry
The padding around usernames.
finalinherited
usernameTextStyle → TextStyle
The text style for usernames.
finalinherited
userStatusColor → Color?
The color for the user's status indicator.
finalinherited
verificationBadge → Widget
A widget to display a verification badge for the user.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited