MessageTheme class

Constructors

MessageTheme({Color? backgroundColor, Color? fixedWaveColor, Color? liveWaveColor, TextStyle? contentTextStyle, TextStyle? boldTextStyle, TextStyle? timeTextStyle, TextStyle? urlTextStyle, TextStyle? linkPreviewTitleStyle, TextStyle? linkPreviewTextStyle, BorderRadiusGeometry? borderRadius, Border? border, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Color? backroundColor, double? messageWidth})
const

Properties

backgroundColor → Color?
The background color for the chat widget.
final
backroundColor → Color?
The background color for inward (received) messages.
final
boldTextStyle → TextStyle?
The text style for URLs in messages.
final
border → Border?
The border for outward (sent) messages.
final
borderRadius → BorderRadiusGeometry?
The border radius for outward (sent) messages.
final
contentTextStyle → TextStyle?
The text style for inward (received) messages.
final
fixedWaveColor → Color?
The text input background color used for various elements in the chat.
final
hashCode → int
The hash code for this object.
no setterinherited
linkPreviewTextStyle → TextStyle?
The text style for the text content in link previews.
final
linkPreviewTitleStyle → TextStyle?
The text style for the title in link previews.
final
liveWaveColor → Color?
final
margin → EdgeInsetsGeometry?
final
messageWidth → double?
The width of messages.
final
padding → EdgeInsetsGeometry?
The padding around messages.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeTextStyle → TextStyle?
The text style for timestamps in messages.
final
urlTextStyle → TextStyle?
The text style for URLs in messages.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited